import { NgModule } from "@angular/core";
import { Routes, RouterModule } from "@angular/router";
import { LoginComponent } from "./login/login.component";
import { HomeComponent } from "./home/home.component";
import { DefaultComponent } from "../layout/default/default.component";

// layout

// single pages

const routes: Routes = [
  { path: "", redirectTo: "/login", pathMatch: "full" },
  { path: "login", component: LoginComponent },
  { path: "home", component: HomeComponent },
  {
    path: "admin",
    component: DefaultComponent,
    children: [
      // 数据分析与展示
      {
        path: "data-view",
        loadChildren: "./data-view/data-view.module#DataViewModule"
      },
      // 文件资料
      {
        path: "file",
        loadChildren: "./file/file.module#FileModule"
      },
      // 固定资产
      {
        path: "fixed-assets",
        loadChildren: "./fixed-assets/fixed-assets.module#FixedAssetsModule"
      },
      // 闲置共享
      {
        path: "idle-shared",
        loadChildren: "./idle-shared/idle-shared.module#IdleSharedModule"
      },
      // 无形资产
      {
        path: "intangible-assets",
        loadChildren:
          "./intangible-assets/intangible-assets.module#IntangibleAssetsModule"
      },
      // 产权管理
      {
        path: "property-management",
        loadChildren:
          "./property-management/property-management.module#PropertyManagementModule"
      },
      // 周转材料低值易耗
      {
        path: "revolving-material",
        loadChildren:
          "./revolving-material/revolving-material.module#RevolvingMaterialModule"
      },
      // 系统设置
      {
        path: "settings",
        loadChildren: "./settings/settings.module#SettingsModule"
      },
      // 用户中心
      {
        path: "user",
        loadChildren: "./user/user.module#UserModule"
      }
    ]
  },
  // 单页不包裹Layout
  { path: "**", redirectTo: "/login" }
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule]
})
export class RouteRoutingModule {}
